import { ElementOrString } from "./interfaces";

declare namespace domStyle {
    interface DomComputedStyle {
		position?: string;
		width?: string;
		height?: string;
		[id: string]: any;
	}

	interface DomStyle {
		/**
		 * Returns a "computed style" object.
		 */
		getComputedStyle(node: Node): DomComputedStyle;

		/**
		 * Accesses styles on a node.
		 */
		get(node: ElementOrString): DomComputedStyle;
		get(node: ElementOrString, name: string): string | number;

		/**
		 * Sets styles on a node.
		 */
		set(node: ElementOrString, name: DomComputedStyle): DomComputedStyle;
		set(node: ElementOrString, name: string, value: string | number): DomComputedStyle;

		/**
		 * converts style value to pixels on IE or return a numeric value.
		 */
		toPixelValue(element: Element, value: string): number;
	}
}

declare const domStyle: domStyle.DomStyle;
export = domStyle;